#[repr(i32)]pub enum TxAction {
Unknown = 0,
Unmodified = 1,
Added = 2,
Removed = 3,
Delayed = 4,
}Expand description
TxAction contains App-provided information on what to do with a transaction that is part of a raw proposal
Variants
Unknown = 0
Unknown action
Unmodified = 1
The Application did not modify this transaction.
Added = 2
The Application added this transaction.
Removed = 3
The Application wants this transaction removed from the proposal and the mempool.
Delayed = 4
The Application wants this transaction removed from the proposal but not the mempool.
Implementations
Sourceimpl TxAction
impl TxAction
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.